@@ -85,6 +85,7 @@ class Cutlet:
         self.use_wo  = (self.system in ('hepburn', 'nihon'))
 
         self.use_foreign_spelling = True
+        self.ensure_ascii = True
 
     def add_exception(self, key, val):
         self.exceptions[key] = val
@@ -114,7 +115,7 @@ class Cutlet:
         # convert all full-width alphanum to half-width, since it can go out as-is
         text = mojimoji.zen_to_han(text, kana=False)
 
-        words = self.tagger.parseToNodeList(text)
+        words = self.tagger(text)
 
         out = ''
 
@@ -161,8 +162,11 @@ class Cutlet:
         # remove any leftover っ
         out = out.replace('っ', '').strip()
         # capitalize the first letter
-        if capitalize:
-            out = out[0].capitalize() + out[1:]
+        if capitalize and len(out) > 0:
+            tmp = out[0].capitalize()
+            if len(out) > 1:
+                tmp += out[1:]
+            out = tmp
         return out
 
     def romaji_word(self, word):
@@ -177,6 +181,25 @@ class Cutlet:
         if is_ascii(word.surface):
             return word.surface
 
+        # deal with unks first
+        if word.is_unk:
+            # at this point is is presumably an unk
+            # Check character type using the values defined in char.def. 
+            # This is constant across unidic versions so far but not guaranteed.
+            print('unk', word.char_type)
+            if word.char_type == 6 or word.char_type == 7: # hiragana/katakana
+                kana = jaconv.kata2hira(word.surface)
+                return self.map_kana(kana)
+
+            # At this point this is an unknown word and not kana. Could be
+            # unknown kanji, could be hangul, cyrillic, something else.
+            # By default ensure ascii by replacing with ?, but allow pass-through.
+            if self.ensure_ascii:
+                out = '?' * len(word.surface)
+                return out
+            else:
+                return word.surface
+
         if word.feature.pos1 == '補助記号':
             # If it's punctuation we don't recognize, just discard it
             return self.table.get(word.surface, '')
@@ -198,6 +221,7 @@ class Cutlet:
             kana = jaconv.kata2hira(word.feature.kana)
             return self.map_kana(kana)
         else:
+            # unclear when we would actually get here
             return word.surface
 
     def map_kana(self, kana):
